@@ -1,6 +1,6 @@
 #import <objectbase/SwarmObject.h>
 #import "Hashtable.h"
-#import "MemLogConsumer.h"
+#import <logzone/MemLogConsumer.h>
 
 // KISS stands for Keep it simple, stupid.
 
